@@ -1,9 +1,7 @@
 package Git::CPAN::Patch;
-BEGIN {
-  $Git::CPAN::Patch::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Patch CPAN modules using Git
-$Git::CPAN::Patch::VERSION = '2.0.4';
+$Git::CPAN::Patch::VERSION = '2.1.0';
 use 5.10.1;
 
 use strict;
@@ -95,7 +93,7 @@ Git::CPAN::Patch - Patch CPAN modules using Git
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
