@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Clone;
-BEGIN {
-  $Git::CPAN::Patch::Command::Clone::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Clone a CPAN module's history into a new git repository
-$Git::CPAN::Patch::Command::Clone::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Clone::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -62,7 +60,7 @@ Git::CPAN::Patch::Command::Clone - Clone a CPAN module's history into a new git
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
