@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::FormatPatch;
-BEGIN {
-  $Git::CPAN::Patch::Command::FormatPatch::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Format patches using C<cpan/master> as the origin reference
-$Git::CPAN::Patch::Command::FormatPatch::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::FormatPatch::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -37,7 +35,7 @@ Git::CPAN::Patch::Command::FormatPatch - Format patches using C<cpan/master> as
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
