@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Import;
-BEGIN {
-  $Git::CPAN::Patch::Command::Import::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import a module into a git repository
-$Git::CPAN::Patch::Command::Import::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Import::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -100,6 +98,14 @@ method clone_git_repo($release,$url) {
     $self->git_run( 'fetch', 'cpan' );
 }
 
+sub looks_like_git {
+    my $repo = shift or return;
+
+    return 1 if $repo->{type} eq 'git';
+
+    return $repo->{url} =~ /github\.com|\.git$/;
+}
+
 method get_releases_from_cpan($dist_or_module) {
     
     # is it a module belonging to a distribution?
@@ -113,7 +119,7 @@ method get_releases_from_cpan($dist_or_module) {
 
     if( my $latest_release = !$self->norepository && $self->metacpan->release($dist)) {
         my $repo = $latest_release->data->{metadata}{resources}{repository};
-        if( $repo and $repo->{type} eq 'git' ) {
+        if ( looks_like_git($repo) ) {
             say "Git repository found: ", $repo->{url};
             $self->clone_git_repo(Git::CPAN::Patch::Release->new( 
                 metacpan => $self->metacpan,
@@ -263,7 +269,7 @@ Git::CPAN::Patch::Command::Import - Import a module into a git repository
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
