@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::SendEmail;
-BEGIN {
-  $Git::CPAN::Patch::Command::SendEmail::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: use C<git-send-email> to submit patches to CPAN RT
-$Git::CPAN::Patch::Command::SendEmail::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::SendEmail::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -42,7 +40,7 @@ Git::CPAN::Patch::Command::SendEmail - use C<git-send-email> to submit patches t
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
