@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::SendPatch;
-BEGIN {
-  $Git::CPAN::Patch::Command::SendPatch::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: create patch files and submit them to RT
-$Git::CPAN::Patch::Command::SendPatch::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::SendPatch::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -47,7 +45,7 @@ Git::CPAN::Patch::Command::SendPatch - create patch files and submit them to RT
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
