@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Sources;
-BEGIN {
-  $Git::CPAN::Patch::Command::Sources::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: lists sources for the module
-$Git::CPAN::Patch::Command::Sources::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Sources::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -122,7 +120,7 @@ Git::CPAN::Patch::Command::Sources - lists sources for the module
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
