@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Squash;
-BEGIN {
-  $Git::CPAN::Patch::Command::Squash::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Combine multiple commits into one patch
-$Git::CPAN::Patch::Command::Squash::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Squash::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -59,7 +57,7 @@ Git::CPAN::Patch::Command::Squash - Combine multiple commits into one patch
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
