@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Update;
-BEGIN {
-  $Git::CPAN::Patch::Command::Update::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import the latest version of a module and rebase the current branch
-$Git::CPAN::Patch::Command::Update::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Update::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -52,7 +50,7 @@ Git::CPAN::Patch::Command::Update - Import the latest version of a module and re
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
