@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Command::Which;
-BEGIN {
-  $Git::CPAN::Patch::Command::Which::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: reports the repository's module
-$Git::CPAN::Patch::Command::Which::VERSION = '2.0.4';
+$Git::CPAN::Patch::Command::Which::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -35,7 +33,7 @@ Git::CPAN::Patch::Command::Which - reports the repository's module
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 SYNOPSIS
 
