@@ -1,8 +1,6 @@
 package Git::CPAN::Patch::Import;
-BEGIN {
-  $Git::CPAN::Patch::Import::AUTHORITY = 'cpan:YANICK';
-}
-$Git::CPAN::Patch::Import::VERSION = '2.0.4';
+our $AUTHORITY = 'cpan:YANICK';
+$Git::CPAN::Patch::Import::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -538,7 +536,7 @@ Git::CPAN::Patch::Import
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 DESCRIPTION
 
