@@ -1,8 +1,6 @@
 package Git::CPAN::Patch::Release;
-BEGIN {
-  $Git::CPAN::Patch::Release::AUTHORITY = 'cpan:YANICK';
-}
-$Git::CPAN::Patch::Release::VERSION = '2.0.4';
+our $AUTHORITY = 'cpan:YANICK';
+$Git::CPAN::Patch::Release::VERSION = '2.1.0';
 use strict;
 use warnings;
 
@@ -233,7 +231,7 @@ Git::CPAN::Patch::Release
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 AUTHOR
 
