@@ -1,9 +1,7 @@
 package Git::CPAN::Patch::Role::Git;
-BEGIN {
-  $Git::CPAN::Patch::Role::Git::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: provides access to Git repository
-$Git::CPAN::Patch::Role::Git::VERSION = '2.0.4';
+$Git::CPAN::Patch::Role::Git::VERSION = '2.1.0';
 use strict;
 use warnings;
 
@@ -81,7 +79,7 @@ Git::CPAN::Patch::Role::Git - provides access to Git repository
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 AUTHOR
 
