@@ -1,8 +1,6 @@
 package Git::CPAN::Patch::Role::Patch;
-BEGIN {
-  $Git::CPAN::Patch::Role::Patch::AUTHORITY = 'cpan:YANICK';
-}
-$Git::CPAN::Patch::Role::Patch::VERSION = '2.0.4';
+our $AUTHORITY = 'cpan:YANICK';
+$Git::CPAN::Patch::Role::Patch::VERSION = '2.1.0';
 use 5.10.0;
 
 use strict;
@@ -69,7 +67,7 @@ Git::CPAN::Patch::Role::Patch
 
 =head1 VERSION
 
-version 2.0.4
+version 2.1.0
 
 =head1 AUTHOR
 
